package org.rcisoft.bus.taskinfo.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.bus.taskinfo.entity.TaskInfo;
import org.rcisoft.bus.taskinfo.service.TaskInfoService;

import java.util.List;

/**
* Created by cy on 2024年5月15日 下午6:59:06.
*/
@RestController
@RequestMapping("/taskinfo")
public class TaskInfoController extends CyPaginationController<TaskInfo> {


    @Autowired
    private TaskInfoService taskInfoServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:kInfo:add')")
    @CyOpeLogAnno(title = "system-?????管理-新增?????", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加?????", notes="添加?????")
    @PostMapping(value = "/add")
    public CyResult add(@Valid TaskInfo taskInfo, BindingResult bindingResult) {
        CyPersistModel data = taskInfoServiceImpl.persist(taskInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        taskInfo);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:kInfo:delete')")
    @CyOpeLogAnno(title = "system-?????管理-删除?????", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除?????", notes="逻辑删除?????")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId,TaskInfo taskInfo) {
        taskInfo.setBusinessId(businessId);
        CyPersistModel data = taskInfoServiceImpl.removeLogical(taskInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:kInfo:delete')")
    @CyOpeLogAnno(title = "system-?????管理-删除?????", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除?????", notes="删除?????")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,TaskInfo taskInfo) {
        taskInfo.setBusinessId(businessId);
        CyPersistModel data = taskInfoServiceImpl.remove(taskInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:kInfo:update')")
    @CyOpeLogAnno(title = "system-?????管理-修改?????", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改?????", notes="修改?????")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid TaskInfo taskInfo, BindingResult bindingResult) {
        taskInfo.setBusinessId(businessId);
        CyPersistModel data = taskInfoServiceImpl.merge(taskInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        taskInfo);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:kInfo:query')")
    @CyOpeLogAnno(title = "system-?????管理-查询?????", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一?????", notes="查询单一?????")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        taskInfoServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:kInfo:list')")
    @CyOpeLogAnno(title = "system-?????管理-查询?????", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询?????集合", notes="查询?????集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(TaskInfo taskInfo) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            taskInfoServiceImpl.findAll(taskInfo));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:kInfo:list')")
    @CyOpeLogAnno(title = "system-?????管理-查询?????", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询?????集合", notes="分页查询?????集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(TaskInfo taskInfo) {
        taskInfoServiceImpl.findAllByPagination(getPaginationUtility(), taskInfo);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-?????管理-查询?????", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出?????信息", notes = "导出?????信息")
    @GetMapping(value = "/export")
    public void outTaskInfo(HttpServletResponse response,TaskInfo taskInfo,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="?????信息.xls";break;
            case "1": excelName="?????信息.xlsx";break;
            case "2": excelName="?????信息.csv";break;
        }
        List<TaskInfo> taskInfoList = taskInfoServiceImpl.export(taskInfo);
        CyEpExcelUtil.exportExcel(taskInfoList, "?????信息", "?????信息", TaskInfo.class, excelName, response);
    }
}
